"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const emitter = require("ts-emitter");
const ts = require("typescript");
class Collection {
    constructor(collected, root) {
        this.root = root;
        this.collected = collected;
    }
    static fromSource(source) {
        const file = emitter.fromSource(source);
        return new Collection([file], file);
    }
    static fromNode(node) {
        return new Collection([node], node);
    }
    find(kind, pattern) {
        const marked = [];
        const visitor = (node) => {
            if (node.kind === kind) {
                if (pattern) {
                    switch (node.kind) {
                        case ts.SyntaxKind.Identifier:
                            this.matchIdentifier(marked, node, pattern);
                    }
                }
                else {
                    marked.push(node);
                }
            }
            else {
                ts.forEachChild(node, visitor);
            }
        };
        this.collected.forEach(node => {
            ts.forEachChild(node, visitor);
        });
        return new Collection(marked, this.root);
    }
    matchIdentifier(marked, node, pattern) {
        if (node.text === pattern.name) {
            marked.push(node);
        }
    }
    replaceWith(fn) {
        const replacer = (context) => (rootNode) => {
            const visitor = (node) => {
                const markedNode = this.collected.find(item => item === node);
                if (markedNode) {
                    const replaced = fn(markedNode);
                    replaced.original = markedNode;
                    if (replaced.text && replaced.text !== markedNode.text) {
                        replaced.newText = replaced.text;
                    }
                    return replaced;
                }
                return ts.visitEachChild(node, visitor, context);
            };
            return ts.visitNode(rootNode, visitor);
        };
        this.root = ts.transform(this.root, [replacer]).transformed[0];
        return this;
    }
    size() {
        return this.collected.length;
    }
    toSource() {
        if (this.root.kind !== ts.SyntaxKind.SourceFile) {
            throw new Error(`toSource() could only be called on collections of type `
                + `'ts.SourceFile' but this is of type '${ts.SyntaxKind[this.root.kind]}'`);
        }
        return emitter.toSource(this.root);
    }
}
exports.Collection = Collection;
