#!/usr/bin/env node
"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs-extra");
const globby = require("globby");
const meow = require("meow");
const collection_1 = require("./collection");
const api = {
    tscodeshift: (source) => {
        if (typeof source === 'string') {
            return collection_1.Collection.fromSource(source);
        }
        else {
            return collection_1.Collection.fromNode(source);
        }
    }
};
function main(cli) {
    return __awaiter(this, void 0, void 0, function* () {
        const transformPaths = [].concat(cli.flags['t'] || [], cli.flags['transform'] || []);
        const transforms = transformPaths.map(path => require(path).default);
        const paths = yield globby(cli.input);
        paths.forEach((path) => __awaiter(this, void 0, void 0, function* () {
            const source = (yield fs.readFile(path)).toString();
            const result = applyTransforms(path, source, transforms);
            yield fs.writeFile(path, result);
        }));
    });
}
/* @internal */
function applyTransforms(path, source, transforms) {
    const file = {
        path,
        source
    };
    return transforms
        .reduce((file, transform) => {
        return {
            path: file.path,
            source: transform(file, api)
        };
    }, file)
        .source;
}
exports.applyTransforms = applyTransforms;
const cli = meow(`
  Usage: tscodeshift <path>... [options]

  path     Files or directory to transform

  Options:
    -t FILE, --transform FILE   Path to the transform file. Can be either a local path or url  [./transform.js]
`);
main(cli)
    .catch(e => {
    console.log('Failed to run tscodeshift.', e, e.stack);
    process.exit(1);
});
